==> im-sdk_11.4.1483.orig.tar.gz: im-sdk-r11_4-1483/iiimxcf/xiiimp.so/iiimp/xfactory.h <==
/*
Copyright 1990-2001 Sun Microsystems, Inc. All Rights Reserved.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions: The above copyright notice and this
permission notice shall be included in all copies or substantial
portions of the Software.


THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE OPEN GROUP OR SUN MICROSYSTEMS, INC. BE LIABLE
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE EVEN IF
ADVISED IN ADVANCE OF THE POSSIBILITY OF SUCH DAMAGES.


Except as contained in this notice, the names of The Open Group and/or
Sun Microsystems, Inc. shall not be used in advertising or otherwise to
promote the sale, use or other dealings in this Software without prior
written authorization from The Open Group and/or Sun Microsystems,
Inc., as applicable.


X Window System is a trademark of The Open Group

OSF/1, OSF/Motif and Motif are registered trademarks, and OSF, the OSF
logo, LBX, X Window System, and Xinerama are trademarks of the Open
Group. All other trademarks and registered trademarks mentioned herein
are the property of their respective owners. No right, title or
interest in or to any trademark, service mark, logo or trade name of
Sun Microsystems, Inc. or its licensors is granted.

*/

/*
 * $Id: xfactory.h,v 1.1.1.1.2.2 2002/09/27 01:57:30 himi Exp $
 */

#ifndef _XFACTORY_H
#define _XFACTORY_H

#pragma ident	"@(#)xfactory.h 1.1	99/11/04 SMI"

extern void	XFactoryRemoveDecoration(Display *display, Window window);
extern void	XFactoryRemoveDecorationExceptTitle(Display *display,
						    Window window);
extern void	XFactoryRemoveAllDecoration(Display *display, Window window);
extern void	XFactoryRemoveMenu(Display *display, Window window);
extern void	XFactoryRemoveBorder(Display *display, Window window);
extern Window	XFactoryGetFrameWindow(Display *display, Window window);
extern Window	XFactoryGetToplevelWindow(Display *display, Window window);
extern void	XFactoryGetLocationOnScreen(Display *display, Window window,
					    int x, int y, XPoint *point);
extern Window	XFactoryCreateIMWindow(Display *display, Window parent,
				       Window transient_win,
				       int x, int y,
				       unsigned int width, unsigned int height,
				       unsigned long bg, long event_mask,
				       XIMFilter filters, int count);
extern void	XFactoryAdjustPlacementInsideScreen(Display * dpy, Window win,
						    int x, int y,
						    int width, int height,
						    int * ret_x, int * ret_y);
extern int	XFactoryResizeWindowInsideScreen(Display * display, Window w,
						 unsigned int width,
						 unsigned int height);
extern int	XFactoryMoveResizeWindowInsideScreen(Display * display,
						     Window w,
						     int x, int y,
						     unsigned int width,
						     unsigned int height);
extern int	XFactoryMoveWindowInsideScreen(Display * display, Window w,
					       int x, int y);

extern XFontSet XFactoryCreateDefaultFontSet (Display *display);
extern void	XFactoryFreeDefaultFontSet(Display *display);

extern Bool     XFactoryCheckIMWindow(Display* display, Window window);
extern int      XFactoryValidateCoordinates(Display * display, Window w,
					    int *x, int *y);
#endif /* !_XFACTORY_H */

==> im-sdk_11.4.1870.orig.tar.gz: im-sdk-r11_4-1870/iiimxcf/xiiimp.so/iiimp/xfactory.h <==
/*
Copyright 1990-2001 Sun Microsystems, Inc. All Rights Reserved.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions: The above copyright notice and this
permission notice shall be included in all copies or substantial
portions of the Software.


THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE OPEN GROUP OR SUN MICROSYSTEMS, INC. BE LIABLE
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE EVEN IF
ADVISED IN ADVANCE OF THE POSSIBILITY OF SUCH DAMAGES.


Except as contained in this notice, the names of The Open Group and/or
Sun Microsystems, Inc. shall not be used in advertising or otherwise to
promote the sale, use or other dealings in this Software without prior
written authorization from The Open Group and/or Sun Microsystems,
Inc., as applicable.


X Window System is a trademark of The Open Group

OSF/1, OSF/Motif and Motif are registered trademarks, and OSF, the OSF
logo, LBX, X Window System, and Xinerama are trademarks of the Open
Group. All other trademarks and registered trademarks mentioned herein
are the property of their respective owners. No right, title or
interest in or to any trademark, service mark, logo or trade name of
Sun Microsystems, Inc. or its licensors is granted.

*/

/*
 * $Id: xfactory.h,v 1.2 2004/01/29 01:15:36 tajima Exp $
 */

#ifndef _XFACTORY_H
#define _XFACTORY_H

#pragma ident	"@(#)xfactory.h 1.1	99/11/04 SMI"

extern void	XFactoryRemoveDecoration(Display *display, Window window);
extern void	XFactoryRemoveDecorationExceptTitle(Display *display,
						    Window window);
extern void	XFactoryRemoveAllDecoration(Display *display, Window window);
extern void	XFactoryRemoveMenu(Display *display, Window window);
extern void	XFactoryRemoveBorder(Display *display, Window window);
extern Window	XFactoryGetFrameWindow(Display *display, Window window);
extern Window	XFactoryGetToplevelWindow(Display *display, Window window);
extern void	XFactoryGetLocationOnScreen(Display *display, Window window,
					    int x, int y, XPoint *point);
extern Window	XFactoryCreateIMWindow(Display *display, Window parent,
				       Window transient_win,
				       int x, int y,
				       unsigned int width, unsigned int height,
				       unsigned long bg, long event_mask,
				       XIMFilter filters, int count);
extern void	XFactoryAdjustPlacementInsideScreen(Display * dpy, Window win,
						    int x, int y,
						    int width, int height,
						    int * ret_x, int * ret_y);
extern int	XFactoryResizeWindowInsideScreen(Display * display, Window w,
						 unsigned int width,
						 unsigned int height);
extern int	XFactoryMoveResizeWindowInsideScreen(Display * display,
						     Window w,
						     int x, int y,
						     unsigned int width,
						     unsigned int height);
extern int	XFactoryMoveWindowInsideScreen(Display * display, Window w,
					       int x, int y);

extern XFontSet XFactoryCreateDefaultFontSet (Display *display,
					      char *default_font_name);
extern void	XFactoryFreeDefaultFontSet(Display *display);

extern Bool     XFactoryCheckIMWindow(Display* display, Window window);
extern int      XFactoryValidateCoordinates(Display * display, Window w,
					    int *x, int *y);
#endif /* !_XFACTORY_H */
